@@ -1,28 +1,9 @@
 package Data::FormValidator::Constraints::DateTime;
 use strict;
-use base 'Exporter';
 use DateTime;
 use DateTime::Format::Strptime;
 
-our $VERSION = '0.02';
-our @EXPORT_OK = qw(
-    match_to_datetime
-    match_to_mysql_datetime
-    match_to_mysql_date
-    match_to_mysql_timestamp
-    match_to_pg_datetime
-);
-our %EXPORT_FLAGS = (
-    all     => \@EXPORT_OK,
-    mysql   => [qw(
-        to_mysql_datetime
-        to_mysql_date
-        to_mysql_timestamp
-    )],
-    pg      => [qw(
-        to_pg_datetime
-    )],
-);
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -50,6 +31,7 @@ various database engines.
           my_date   => {
             constraint_method   => 'to_datetime',
             params              => [\'%D'], # some valid strptime format string
+          },
       },
       untaint_all_constraints => 1,
   };
@@ -76,37 +58,16 @@ them to memory) you can see the strptime(3) man page (if you are
 on a *nix system) or you can see the L<DateTime::Format::Strptime> 
 documentation.
 
+There are however some routines that can live without the format
+param. These include routines which try and validate according
+to rules for a particular database (C<< to_mysql_* >> and 
+C<< to_pg_* >>). If no format is provided, then we will attempt to
+validate according to the rules for that datatype in that database
+(using L<DateTime::Format::MySQL> and L<DateTime::Format::Pg>). See
+each validation routine for examples.
+
 =head1 VALIDATION ROUTINES
 
-By default, this module does not export any validation routines.
-You should export the group of methods that you are going to use.
-
-=over 8
-
-=item all - exports all routines
-
-=item mysql - exports all MySQL related routines. These include
-
-=over 8
-
-=item * to_mysql_datetime
-
-=item * to_mysql_date
-
-=item * to_mysql_timestamp
-
-=back
-
-=item pg - exports all PostgreSQL related routines. These include
-
-=over 8
-
-=item * to_pg_datetime
-
-=back
-
-=back
-
 Following is a list of validation subroutines that can be exported
 by this module.
 
@@ -125,8 +86,6 @@ sub match_to_datetime {
 
 sub _get_datetime {
     my ($self, $format) = @_;
-    die "needs format as 'param' and must be a scalar ref"
-        unless( $format && (ref $format eq 'SCALAR') );
     $format = $$format;
     # create the formatter
     my $formatter = DateTime::Format::Strptime->new(
@@ -149,12 +108,26 @@ suitable for MySQL
 
 sub match_to_mysql_datetime {
     my ($self, $format) = @_;
-    # get the DateTime
-    my $dt = _get_datetime($self, $format);
+
+    # make sure they have DateTime::Format::MySQL
+    eval { require DateTime::Format::MySQL; };
+    die "DateTime::Format::MySQL is required to use this routine"
+        if( $@ );
+    my $dt;
+
+    # if they gave us a format (through params as a scalar ref)
+    # then translate the value
+    if( ref $format eq 'SCALAR' ) {
+        $dt = _get_datetime($self, $format);
+    # else there is no format, so just use parse_datetime
+    } else {
+        eval { 
+            $dt = DateTime::Format::MySQL->parse_datetime(
+                $self->get_current_constraint_value
+            );
+        };
+    }
     if( $dt ) {
-        eval { require DateTime::Format::MySQL; };
-        die "DateTime::Format::Pg is required to use this routine"
-            if( $@ );
         return DateTime::Format::MySQL->format_datetime($dt); 
     } else {
         return undef;
@@ -170,13 +143,27 @@ suitable for MySQL
 
 sub match_to_mysql_date {
     my ($self, $format) = @_;
-    # get the DateTime
-    my $dt = _get_datetime($self, $format);
+
+    # make sure they have DateTime::Format::MySQL
+    eval { require DateTime::Format::MySQL; };
+    die "DateTime::Format::MySQL is required to use this routine"
+        if( $@ );
+    my $dt;
+
+    # if they gave us a format (through params as a scalar ref)
+    # then translate the value
+    if( ref $format eq 'SCALAR' ) {
+        $dt = _get_datetime($self, $format);
+    # else there is no format, so just use parse_datetime
+    } else {
+        eval { 
+            $dt = DateTime::Format::MySQL->parse_date(
+                $self->get_current_constraint_value
+            );
+        };
+    }
     if( $dt ) {
-        eval { require DateTime::Format::MySQL; };
-        die "DateTime::Format::Pg is required to use this routine"
-            if( $@ );
-        return DateTime::Format::MySQL->format_date($dt); 
+        return DateTime::Format::MySQL->format_date($dt);
     } else {
         return undef;
     }
@@ -191,8 +178,36 @@ suitable for MySQL
 
 sub match_to_mysql_timestamp {
     my ($self, $format) = @_;
-    # get the DateTime
-    my $dt = _get_datetime($self, $format);
+
+    # make sure they have DateTime::Format::MySQL
+    eval { require DateTime::Format::MySQL; };
+    die "DateTime::Format::MySQL is required to use this routine"
+        if( $@ );
+    my $dt;
+
+    # if they gave us a format (through params as a scalar ref)
+    # then translate the value
+    if( ref $format eq 'SCALAR' ) {
+        $dt = _get_datetime($self, $format);
+    # else there is no format, so parse into a timestamp
+    } else {
+        my $string = $self->get_current_constraint_value();
+        # if it matches a timestamp format YYYYMMDDHHMMSS
+        # but we're actually a little looser than that... we take
+        # YYYY-MM-DD HH:MM:SS with any other potential separators
+        if( $string =~ /(\d{4})\D*(\d{2})\D*(\d{2})\D*(\d{2})\D*(\d{2})\D*(\d{2})/ ) {
+            eval { 
+                $dt = DateTime->new(
+                    year    => $1,
+                    month   => $2,
+                    day     => $3,
+                    hour    => $4,
+                    minute  => $5,
+                    second  => $6,
+                );
+            };
+        }
+    }
     if( $dt ) {
         return $dt->ymd('') . $dt->hms('');
     } else {
@@ -209,12 +224,26 @@ suitable for PostgreSQL
 
 sub match_to_pg_datetime {
     my ($self, $format) = @_;
-    # get the DateTime
-    my $dt = _get_datetime($self, $format);
+
+    # make sure they have DateTime::Format::MySQL
+    eval { require DateTime::Format::Pg; };
+    die "DateTime::Format::Pg is required to use this routine"
+        if( $@ );
+    my $dt;
+
+    # if they gave us a format (through params as a scalar ref)
+    # then translate the value
+    if( ref $format eq 'SCALAR' ) {
+        $dt = _get_datetime($self, $format);
+    # else there is no format, so just use parse_datetime
+    } else {
+        eval {
+            $dt = DateTime::Format::Pg->parse_datetime(
+                $self->get_current_constraint_value
+            );
+        };
+    }
     if( $dt ) {
-        eval { require DateTime::Format::Pg; };
-        die "DateTime::Format::Pg is required to use this routine"
-            if( $@ );
         return DateTime::Format::Pg->format_datetime($dt);
     } else {
         return undef;
